@@ -4,7 +4,7 @@
 #' @include Terminator.R
 #'
 #' @description
-#' Mainly useful for optimization algorithms where the stopping is inherently controlled by the algorithm itself (e.g. [OptimizerGridSearch]).
+#' Mainly useful for optimization algorithms where the stopping is inherently controlled by the algorithm itself (e.g. [OptimizerBatchGridSearch]).
 #'
 #' @templateVar id none
 #' @template section_dictionary_terminator
@@ -35,7 +35,7 @@ TerminatorNone = R6Class("TerminatorNone",
     #'
     #' @return `logical(1)`.
     is_terminated = function(archive) {
-      assert_r6(archive, "Archive")
+      assert_multi_class(archive, c("Archive", "ArchiveAsync"))
       return(FALSE)
     }
   )
